/*
(C) 2007 Katsutoshi YAGISHITA (yagisita@spnet.ne.jp)
*/

var targetprices = new Array();

function etrdTargetpriceObject(code, target, warn, name, low, high)
{
	this.code = code;
	this.target = target;
	this.warn = (!isNaN(warn)) ? warn : 0;
	this.name = null;
	if (name)
		this.name = name;
	this.warnlow = (!isNaN(low)) ? low : 0;
	this.warnhigh = (!isNaN(high)) ? high : 0;
}

function setTargetPriceImpl(code, target, warn, name, low, high)
{
	var i;
	for (i = 0; i < targetprices.length; ++i) {
		if (targetprices[i].code == code)
			break;
	}
	if (i == targetprices.length)	
		targetprices[i] = new etrdTargetpriceObject(code, target, warn, name, low, high);
	else {
		if (target != null)
			targetprices[i].target = (target.length > 0) ? target : null;
		if (!isNaN(warn))
			targetprices[i].warn = warn;
		if (name && name.length > 0)
			targetprices[i].name = name;
		if (low && !isNaN(low))
			targetprices[i].warnlow = low;
		if (high && !isNaN(high))
			targetprices[i].warnhigh = high;
	}
}

function getTargetPriceImpl(code)
{
	var i;
	for (i = 0; i < targetprices.length; ++i) {
		if (targetprices[i].code == code)
			return targetprices[i];
	}

	return null;
}


function setTargetPrice(code, price, name)
{
	setTargetPriceImpl(code, price, NaN, name, NaN, NaN);
}

function setTargetPriceString(code, price, name)
{
	setTargetPrice(code, (price) ? price : "", name);
}

function setWarnPrice(code, price, name)
{
	setTargetPriceImpl(code, null, (!isNaN(price)) ? price : 0, name, NaN, NaN);
}

function setWarnPriceWithCommaNumberString(code, price, name)
{
	var n = parseCommaNumberString(price);
	setWarnPrice(code, n, name);
}

function setWarnLowPriceWithCommaNumberString(code, low, name)
{
	var n = parseCommaNumberString(low);
	setTargetPriceImpl(code, null, NaN, name, low, NaN);
}

function setWarnHighPriceWithCommaNumberString(code, high, name)
{
	var n = parseCommaNumberString(high);
	setTargetPriceImpl(code, null, NaN, name, NaN, high);
}

function getTargetPrice(code)
{
	var o = getTargetPriceImpl(code);
	return (o) ? o.target : null;
}

function getTargetPriceString(code)
{
	var s = getTargetPrice(code);
	return (s) ? s : "";
}

function getWarnPrice(code)
{
	var o = getTargetPriceImpl(code);
	return (o) ? o.warn : 0;
}

function getWarnPriceWithCommaNumberString(code)
{
	var n = getWarnPrice(code);
	return (n != 0) ? formatCommaNumberString(n, true) : "";
}

function getWarnLowPrice(code)
{
	var o = getTargetPriceImpl(code);
	return (o) ? o.warnlow : 0;
}

function getWarnLowPriceWithCommaNumberString(code)
{
	var n = getWarnLowPrice(code);
	return (n != 0) ? formatCommaNumberString(n, false) : "";
}

function getWarnHighPrice(code)
{
	var o = getTargetPriceImpl(code);
	return (o) ? o.warnhigh : 0;
}

function getWarnHighPriceWithCommaNumberString(code)
{
	var n = getWarnHighPrice(code);
	return (n != 0) ? formatCommaNumberString(n, false) : "";
}


function checkIsWarn(code, current)
{
	var n = parseCommaNumberString(current);
	var m = getWarnPrice(code);
	var l = getWarnLowPrice(code);
	var h = getWarnHighPrice(code);
	if (!isNaN(n) && l != 0) {
		if (n <= Math.abs(l) && (h == 0 || n < h))
			return -2;
	}
	if (!isNaN(n) && h != 0) {
		if (n >= h && (l == 0 || n >= Math.abs(l)))
			return 2;
	}
	if (!isNaN(n) && m != 0) {
		if (m < 0) {
			if (n <= Math.abs(m))
				return -1;
		}
		else if (m > 0) {
			if (n >= m)
				return 1;
		}
	}

	return 0;
}


var targetpriceTop = "ETM2TargetPrices";
var targetprice_tag_name = "targetprice";
var targetprice_paramname_code = "code";
var targetprice_paramname_name = "name";
var targetprice_paramname_warn = "warn";
var targetprice_paramname_warnlow = "warnlow";
var targetprice_paramname_warnhigh = "warnhigh";

function clearPriceTargetList()
{
	targetprices = new Array();
}

function createPriceTargetList(t, x)
{
	if (!x) {
		x = document.createElement("DIV");
		x.innerHTML = t;
	}

	var wps = x.getElementsByTagName(targetprice_tag_name);
	var i;
	for (i = 0; i < wps.length; ++i) {
		var code = wps[i].getAttribute(targetprice_paramname_code);
		var val = getSpecifiedChildOfElement(wps[i]);
		var warn = wps[i].getAttribute(targetprice_paramname_warn);
		var name = wps[i].getAttribute(targetprice_paramname_name);
		var low = wps[i].getAttribute(targetprice_paramname_warnlow);
		var high = wps[i].getAttribute(targetprice_paramname_warnhigh);
		if (code) {
			if (val)
				setTargetPriceString(code, val, name);
			if (warn)
				setWarnPriceWithCommaNumberString(code, warn, name);
			if (low)
				setWarnLowPriceWithCommaNumberString(code, low, name);
			if (high)
				setWarnHighPriceWithCommaNumberString(code, high, name);
		}
	}
}

function loadPriceTargetList(u, isnew, f)
{
	if (!u)
		return;

	if (isnew)
		clearPriceTargetList();

	var o = new XMLHttpRequest();
	o.onreadystatechange = function () {
		if (o.readyState == 4) {
			createPriceTargetList(o.responseText, o.responseXML);
			if (f)
				f();
		}
	};
	if (navigator.userAgent.indexOf("Firefox") >= 0)
		o.overrideMimeType("text/plain; charset=Shift_JIS");

	o.open("GET", u);
	o.setRequestHeader("If-Modified-Since", "Fri, 28 Mar 1975 12:00:00 GMT");
	o.send(null);
}


function createPriceTargetElementString(code, name, price, warn, low, high)
{
	var value = "";
	if (price)
		value = price;
	var warnstr = "";
	if (warn && !isNaN(warn))
		warnstr = formatCommaNumberString(warn, true);
	var warnlowstr = "";
	if (low && !isNaN(low))
		warnlowstr = formatCommaNumberString(low, false);
	var warnhighstr = "";
	if (high && !isNaN(high))
		warnhighstr = formatCommaNumberString(high, false);

	return "<" + targetprice_tag_name + " " + targetprice_paramname_code + "=\"" + code + "\"" + ((name) ? (" " + targetprice_paramname_name + "=\"" + name + "\"") : "") + ((warnstr.length > 0) ? (" " + targetprice_paramname_warn + "=\"" + warnstr + "\"") : "") + ((warnlowstr.length > 0) ? (" " + targetprice_paramname_warnlow + "=\"" + warnlowstr + "\"") : "") + ((warnhighstr.length > 0) ? (" " + targetprice_paramname_warnhigh + "=\"" + warnhighstr + "\"") : "") + ">" + value + "</" + targetprice_tag_name + ">";
}

function getPricetargetArrayAsElementStrings()
{
	var s = "";

	var i;
	for (i = 0; i < targetprices.length; ++i) {
		if (targetprices[i].target || targetprices[i].warn || targetprices[i].warnlow || targetprices[i].warnhigh)
			s = s + (createPriceTargetElementString(targetprices[i].code, targetprices[i].name, targetprices[i].target, targetprices[i].warn, targetprices[i].warnlow, targetprices[i].warnhigh) + "\n");
	}

	return s;
}
